SystemOrganization addCategory: #ConfigurationOfGitFileTree!

Object subclass: #ConfigurationOfGitFileTree
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfGitFileTree'!

!ConfigurationOfGitFileTree commentStamp: '<historical>' prior: 0!
This configuration is for loading gitfiletree on Pharo3.0 with the correct dependencies.

This works on Linux and Mac OS X. Access to git on Windows is however not yet possible due to deficiencies in the ability of Pharo to call external commands.!

!ConfigurationOfGitFileTree class methodsFor: 'development support' stamp: 'ThierryGoubier 2/1/2015 09:53'!
DevelopmentSupport
	"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."

	<apiDocumentation>
	! !

!ConfigurationOfGitFileTree class methodsFor: 'private' stamp: 'ThierryGoubier 1/16/2014 14:13'!
baseConfigurationClassIfAbsent: aBlock
	^ Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ]! !

!ConfigurationOfGitFileTree class methodsFor: 'catalog' stamp: 'ThierryGoubier 1/16/2014 14:37'!
catalogChangeLog
	^ '
Time: jeudi 16 janvier 2014, 14:36:59 (UTC+0100)

First version to get a simple way to load the dependencies of gitfiletree://
'! !

!ConfigurationOfGitFileTree class methodsFor: 'catalog' stamp: 'ThierryGoubier 1/16/2014 14:37'!
catalogContactInfo
	^ 'https://github.com/ThierryGoubier'! !

!ConfigurationOfGitFileTree class methodsFor: 'catalog' stamp: 'ThierryGoubier 3/27/2014 15:18'!
catalogDescription
	^ 'GitFileTree is an integration of Git commands below Monticello, allowing a very simple and powerfull integration with a git repository for tracking Monticello packages, allowing for example one to work from github.com (including with configurations support) without any use of the command line and with perfect support of whatever is the structure of the project under git.

Works with any possible organisation of the git repository related to the package (single language, multi language, single package, multiple packages, single remote repo, multiple remote repositories, branches, you name it).

GitFileTree: is partially integrated into the original FileTree, but not easily available. This configuration allow for a one step loading with the dependencies.'! !

!ConfigurationOfGitFileTree class methodsFor: 'catalog' stamp: 'ThierryGoubier 3/27/2014 15:46'!
catalogKeyClassesAndExample
	^ '
gitfiletree rely on two things :
- FileTree to write a package as a file hierarchy on disk.
- Git commands to
	- commit a package to the repo as soon as it has been written
	- query the repository
	- extract a specific commit of the package directory
	- push and pull from the origin repository
On top of that, gitfiletree does the following:
	- Present a complete MC repository GUI with all versions in the history
	- Read any version in the history of the repository
	- Rebuilt all the MC metadata out of the git history.
Works with any possible organisation of the git repository related to the package (single language, multi language, single package, multiple packages, single remote repo, multiple remote repositories, branches, you name it).

Single principle : does one commit per version of a package. Commit message is the version message in Monticello.

How to use it:
	Install from the Configuration (via the configuration browser).
	From scratch:
		On the command line, create a git repository on a directory
			$ git init
		In the Monticello Browser, do
			+ Repository
		Choose the Repository type:
			gitfiletree://
		Choose the directory in which you have created your git repository above.
		Use then as any other Monticello repository.
	From an existing git repo such as https://github.com/ExampleUser/ExampleProject
		In the Monticello Browser, do
			+ Repository
		Choose the Repository type:
			Remote git repository
		Type the relevant links:
			location: ''git@github.com:ExampleUser/ExampleProject.git''
			name: ''ExampleProject''
			subdirectory: ''''
			branch: ''''
		Use then as any other Monticello repository.	
		Use the Push and Pull buttons in the repository browser (Monticello Browser "Open" button) to update the remote git repository.
'! !

!ConfigurationOfGitFileTree class methodsFor: 'catalog' stamp: 'ThierryGoubier 3/27/2014 15:25'!
catalogKeywords
	^ #(#Packages #FileTree #git #Monticello #OSProcess)! !

!ConfigurationOfGitFileTree class methodsFor: 'private' stamp: 'ThierryGoubier 1/16/2014 14:12'!
ensureMetacello
	(self baseConfigurationClassIfAbsent: [  ]) ensureMetacello! !

!ConfigurationOfGitFileTree class methodsFor: 'private' stamp: 'ThierryGoubier 1/16/2014 14:12'!
ensureMetacelloBaseConfiguration
	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			#('http://smalltalkhub.com/mc/dkh/metacello/main' 'http://seaside.gemtalksystems.com/ss/metacello')
				do: [ :url | 
					| repository version |
					repository := MCHttpRepository location: url user: '' password: ''.
					repository
						versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.19.mcz'
						do: [ :reader | 
							version := reader version.
							version load.
							version workingCopy repositoryGroup addRepository: repository.
							^ self ] ].
			self error: 'Error bootstrapping Metacello: likely network error. Please try again' ]! !

!ConfigurationOfGitFileTree class methodsFor: 'metacello tool support' stamp: 'ThierryGoubier 1/16/2014 14:13'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"

	^ true! !

!ConfigurationOfGitFileTree class methodsFor: 'loading' stamp: 'ThierryGoubier 1/16/2014 14:13'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^ (self project version: #stable) load! !

!ConfigurationOfGitFileTree class methodsFor: 'loading' stamp: 'ThierryGoubier 1/16/2014 14:13'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^ (self project version: #bleedingEdge) load! !

!ConfigurationOfGitFileTree class methodsFor: 'loading' stamp: 'ThierryGoubier 1/16/2014 14:13'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^ (self project version: #development) load! !

!ConfigurationOfGitFileTree class methodsFor: 'accessing' stamp: 'ThierryGoubier 1/16/2014 14:11'!
project

	^self new project! !

!ConfigurationOfGitFileTree class methodsFor: 'development support' stamp: 'ThierryGoubier 2/1/2015 09:53'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfGitFileTree methodsFor: 'baseline' stamp: 'ThierryGoubier 6/27/2014 15:27'!
baseline01: spec
	<version: '0.1-baseline'>
	spec
		for: #'pharo2.x'
		do: [ 
			spec blessing: #baseline.
			spec repository: 'http://smalltalkhub.com/mc/ThierryGoubier/MonticelloFileTree-Git/main/'.
			spec
				project: 'OSProcess'
				with: [ 
					spec
						repository: 'http://ss3.gemstone.com/ss/MetaRepoForPharo20';
						className: 'ConfigurationOfOSProcess';
						version: '4.5.11';
						loads: #('Core with Output') ].
			spec
				project: 'FileTree'
				with: [ 
					spec
						repository: 'http://ss3.gemstone.com/ss/FileTree';
						className: 'ConfigurationOfFileTree';
						version: '1.0.6.1';
						loads: #('default') ].
			spec package: 'MonticelloFileTree-Git'.
			spec group: 'default' with: #('MonticelloFileTree-Git' 'FileTree' 'OSProcess') ]! !

!ConfigurationOfGitFileTree methodsFor: 'baseline' stamp: 'ThierryGoubier 10/20/2015 16:23'!
baseline02: spec
	<version: '0.2-baseline'>
	spec
		for: #'pharo3.x'
		do: [ 
			spec blessing: #baseline.
			spec repository: 'http://smalltalkhub.com/mc/ThierryGoubier/Alt30/main/'.
			spec
				configuration: 'ProcessWrapper'
					with: [ 
							spec
								versionString: #stable;
								repository: 'http://smalltalkhub.com/mc/Pharo/MetaRepoForPharo30/main' ];
				yourself.
			spec
				project: 'OSProcess'
				with: [ 
					spec
						repository: 'http://smalltalkhub.com/mc/Pharo/MetaRepoForPharo30/main/';
						className: 'ConfigurationOfOSProcess';
						version: #stable;
						loads: #('Core with Output') ].
			spec package: 'MonticelloFileTree-Git'.
			spec group: 'default' with: #('MonticelloFileTree-Git' 'OSProcess' 'ProcessWrapper') ]! !

!ConfigurationOfGitFileTree methodsFor: 'accessing' stamp: 'ThierryGoubier 1/16/2014 14:14'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfGitFileTree methodsFor: 'symbolic versions' stamp: 'ThierryGoubier 10/20/2015 16:21'!
development: spec
	<symbolicVersion: #development>
	spec for: #'pharo2.x' version: '0.2'.
	spec for: #'pharo3.x' version: '0.4'! !

!ConfigurationOfGitFileTree methodsFor: 'accessing' stamp: 'ThierryGoubier 1/16/2014 14:15'!
project
	^ project
		ifNil: [ 
			| constructor |
			"Bootstrap Metacello if it is not already loaded"
			(self class baseConfigurationClassIfAbsent: [  ]) ensureMetacello.	"Construct Metacello project"
			project := MetacelloMCProject new projectAttributes: self customProjectAttributes.
			constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
			project loadType: #linear.	"change to #atomic if desired"
			project ]! !

!ConfigurationOfGitFileTree methodsFor: 'symbolic versions' stamp: 'ThierryGoubier 10/20/2015 16:21'!
stable: spec
	<symbolicVersion: #stable>
	spec for: #'pharo2.x' version: '0.1'.
	spec for: #'pharo3.x' version: '0.3'! !

!ConfigurationOfGitFileTree methodsFor: 'versions' stamp: 'ThierryGoubier 10/10/2014 17:03'!
version01: spec
	<version: '0.1' imports: #('0.1-baseline')>
	spec
		for: #'pharo2.x'
		do: [ 
			spec
				blessing: #stable;
				author: 'ThierryGoubier';
				description: 'Git File Tree: Pharo 2 version of the GitFileTree support'.
			spec project: 'OSProcess' with: [ spec version: '4.5.11' ].
			spec package: 'MonticelloFileTree-Git' with: 'MonticelloFileTree-Git-ThierryGoubier.70' ]! !

!ConfigurationOfGitFileTree methodsFor: 'versions' stamp: 'ThierryGoubier 10/10/2014 17:03'!
version02: spec
	<version: '0.2' imports: #('0.1-baseline')>
	spec
		for: #'pharo2.x'
		do: [ 
			spec
				blessing: #development;
				author: 'ThierryGoubier';
				description: 'Git File Tree: Pharo 2 version of the GitFileTree support'.
			spec project: 'OSProcess' with: [ spec version: '4.5.11' ] ]! !

!ConfigurationOfGitFileTree methodsFor: 'versions' stamp: 'ThierryGoubier 10/20/2015 16:24'!
version03: spec
	<version: '0.3' imports: #('0.2-baseline')>
	spec
		for: #'pharo3.x'
		do: [ 
			spec
				blessing: #stable;
				author: 'ThierryGoubier';
				description: 'Git File Tree: Pharo 3 version of the GitFileTree support'.
			spec package: 'MonticelloFileTree-Git' with: 'MonticelloFileTree-Git-ThierryGoubier.97' ]! !

!ConfigurationOfGitFileTree methodsFor: 'versions' stamp: 'ThierryGoubier 2/4/2015 09:30'!
version04: spec
	<version: '0.4' imports: #('0.2-baseline')>
	spec
		for: #'pharo3.x'
		do: [ 
			spec
				blessing: #development;
				author: 'ThierryGoubier';
				description: 'Git File Tree: Pharo 3 version of the GitFileTree support'.
			spec project: 'OSProcess' with: [ spec version: '4.5.11' ] ]! !
